@@ -1,6 +1,7 @@
 package Dancer::Plugin::NYTProf;
 
 use strict;
+use Capture::Tiny ':all';
 use Dancer::Plugin;
 use base 'Dancer::Plugin';
 use Dancer qw(:syntax);
@@ -9,13 +10,32 @@ use File::stat;
 use File::Temp;
 use File::Which;
 
-our $VERSION = '0.31';
+our $VERSION = '0.40';
 
 
 =head1 NAME
 
 Dancer::Plugin::NYTProf - easy Devel::NYTProf profiling for Dancer apps
 
+=head1 SYNOPSIS
+
+    package MyApp;
+    use Dancer ':syntax';
+
+    # enables profiling and "/nytprof"
+    use Dancer::Plugin::NYTProf;
+
+Or, if you want to enable it only under development environment (as you should!),
+you can do something like:
+
+    package MyApp;
+    use Dancer ':syntax';
+
+    # enables profiling and "/nytprof"
+    if (setting('environment') eq 'development') {
+        eval 'use Dancer::Plugin::NYTProf';
+    }
+
 =head1 DESCRIPTION
 
 A plugin to provide easy profiling for Dancer applications, using the venerable
@@ -47,21 +67,51 @@ Below is an example of the options you can configure:
 
     plugins:
         NYTProf:
+            enabled: 1
             profdir: '/tmp/profiledata'
-            nytprofhtmlpath: '/usr/local/bin/nytprofhtml'
+            nytprofhtml_path: '/usr/local/bin/nytprofhtml'
+            show_durations: 1
+
+=head2 profdir
+
+Where to store profiling data. Defaults to: C<$appdir/nytprof>
+
+=head2 nytprofhtml_path
+
+Path to the C<nytprofhtml> script that comes with L<Devel::NYTProf>. Defaults to
+the first one we can find in your PATH environment. You should only  need to
+change this in very specific environments, where C<nytprofhtml> can't be found by
+this plugin.
+
+=head2 enabled
+
+Profiling comes with a penalty, and even in development environments you might
+want to enable/disable it via configuration file. This lets you do so. You can
+toggle this plugin by setting the C<enabled> option to 0 or 1. It is, of course,
+enabled by default.
 
 More configuration (such as the URL at which output is produced, and options to
 control which requests get profiled) will be added in a future version.  (If
 there's something you'd like to see soon, do contact me and let me know - it'll
 likely get done a lot quicker then!)
 
+=head2 show_durations
+
+When listing profile runs, show the duration of each run, extracted from the
+profiling data.  If you have a lot of profiled runs, this might get slow, so
+this option is provided if you don't need the profile durations displayed when
+listing profiles, preferring a faster list.  Defaults to 1.
+
 =cut
 
 
 my $setting = plugin_setting;
 
+# exit as quickly as possible if plugin is not enabled
+return 1 if exists $setting->{enabled} && $setting->{enabled} != 1;
+
 # Work out where nytprof_html is, or die with a sensible error
-my $nytprofhtml_path = $setting->{nytprofhtml_path} 
+my $nytprofhtml_path = $setting->{nytprofhtml_path}
     || File::Which::which('nytprofhtml')
     or die "Could not find nytprofhtml script.  Ensure it's in your path, "
        . "or set the nytprofhtml_path option in your config.";
@@ -162,25 +212,37 @@ LISTSTART
         # Done in an eval to catch errors (e.g. if a profile run died mid-way,
         # the data will be incomplete
         my ($profile,$duration);
-        eval {
-            $profile = Devel::NYTProf::Data->new({ filename => $fullfilepath});
-        };
-        if ($profile) {
-            $duration = sprintf '%.4f secs', 
-                $profile->attributes->{profiler_duration};
-        } else {
-            $duration = '??? seconds - corrupt profile data?';
+
+        if (!defined $setting->{show_durations} || $setting->{show_durations}) {
+            eval {
+                my ($stdout, $stderr, @result) = Capture::Tiny::capture {
+                    $profile = Devel::NYTProf::Data->new(
+                        { filename => $fullfilepath },
+                    );
+                };
+            };
+            if ($profile) {
+                $duration = sprintf '%.4f secs', 
+                    $profile->attributes->{profiler_duration};
+            } else {
+                $duration = '??? seconds - corrupt profile data?';
+            }
         }
+        $pid = "PID $pid";
         my $url = request->uri_for("/nytprof/$file")->as_string;
-        $html .= qq{<li><a href="$url"">$label</a>}
-               . qq{ (PID $pid, $created, $duration)</li>};
+        $html .= qq{<li><a href="$url"">$label</a> (}
+               . join(',', grep { defined $_ } ($pid, $created, $duration))
+               . qq{)</li>};
     }
 
+    my $nytversion = $Devel::NYTProf::VERSION;
     $html .= <<LISTEND;
 </ul>
 
 <p>Generated by <a href="http://github.com/bigpresh/Dancer-Plugin-NYTProf">
-Dancer::Plugin::NYTProf</a> v$VERSION</p>
+Dancer::Plugin::NYTProf</a> v$VERSION
+(using <a href="http://metacpan.org/dist/Devel::NYTProf">
+Devel::NYTProf</a> v$nytversion)</p>
 </body>
 </html>
 LISTEND
@@ -207,7 +269,7 @@ get '/nytprof/:filename' => sub {
         send_error 'not_found';
         return "No such profile run found.";
     }
-    
+
     # See if we already have the HTML for this run stored; if not, invoke
     # nytprofhtml to generate it
 
@@ -225,16 +287,16 @@ get '/nytprof/:filename' => sub {
         } elsif ($? & 127) {
             die sprintf "'%s' died with signal %d, %s coredump",
                 $nytprofhtml_path,,
-                ($? & 127), 
+                ($? & 127),
                 ($? & 128) ? 'with' : 'without';
         } elsif ($? != 0) {
-            die sprintf "'%s' exited with value %d", 
+            die sprintf "'%s' exited with value %d",
                 $nytprofhtml_path, $? >> 8;
         }
     }
 
     # Redirect off to view it:
-    return redirect '/nytprof/html/' 
+    return redirect '/nytprof/html/'
         . param('filename') . '/index.html';
 
 };
@@ -268,6 +330,8 @@ J. Bobby Lopez (jbobbylopez)
 
 leejo
 
+Breno G. de Oliveira (garu)
+
 
 =head1 BUGS
 
@@ -293,7 +357,7 @@ L<Plack::Middleware::Debug::Profiler::NYTProf>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2011-12 David Precious.
+Copyright 2011-2014 David Precious.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
